/*
 * Bull SAS / OW2 Orchestra
 * Copyright (C) 2011 Bull S.A.S, and individual contributors as indicated
 * by the @authors tag.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */

package org.ow2.orchestra.designer.fileNavigator;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;
import org.ow2.orchestra.util.Misc;
import org.ow2.util.substitution.engine.DefaultSubstitutionEngine;
import org.ow2.util.substitution.resolver.PropertiesResolver;

/**
 * @author diouf-a
 */
public class UtilMakeWorkspaces {

  private static String workspacesPath = null;

  /**
   * This method is used to get the service url and object name properties from
   * conf file orchestra.properties It first checks if the
   * conf/orchestra.properties exists to use it, otherwise it uses the file
   * included in the war to fill the fields service url and object name of this
   * class
   *
   * @throws java.io.IOException
   */
  public static void getOrchestraDesignerProperties() throws IOException {
    InputStream inputStream = null;
    File file = null;
    String tempWorkspaces = null;
    try {
      // rerading the file properties of orchestra
      file = new File("conf/orchestra.properties");
      final Properties properties = new Properties();
      if (file.exists()) {
        inputStream = new FileInputStream(file);
        properties.load(inputStream);
        tempWorkspaces = properties.getProperty("orchestra.designer.workspaces");
      }
      if (tempWorkspaces == null || !file.exists()) {
        // reading the file properties of designer, if no params in orchestra properties
        inputStream = Thread.currentThread().getContextClassLoader().getResourceAsStream("orchestra.properties");
        properties.load(inputStream);
        tempWorkspaces = properties.getProperty("orchestra.designer.workspaces");
        if (tempWorkspaces == null) {
          // throw exception if the path of workspaces in not defined in file properties
          throw new RuntimeException("workspaces not defined");
        }
      }

      // update the properties resolver with the properties system
      PropertiesResolver pr = new PropertiesResolver(System.getProperties());
      // define the substitution engine
      DefaultSubstitutionEngine dse = new DefaultSubstitutionEngine();
      // define the properties of base of substitution engine
      dse.setResolver(pr);

      workspacesPath = dse.substitute(tempWorkspaces);
      File projectsWorkspaces = new File(workspacesPath);


      if (!projectsWorkspaces.exists()) {
        // making of workspaces, if failed it throws a IOException
        if (!projectsWorkspaces.mkdirs()) {
          throw new RuntimeException("impossibility to make the workspaces in " + workspacesPath + "; path defined is incorrect ");

        }

      }
      // check if the rootDirectory is writable
      if (!projectsWorkspaces.canWrite()) {
        throw new RuntimeException("the directory \" " + workspacesPath + "  \"is no writable");
      }

    } finally {
      Misc.close(inputStream);
    }

  }

  public static String getWorkspacesPath() {
    return workspacesPath;
  }

}
